@@ -424,7 +424,7 @@ pub struct User {
 
     #[serde(rename = "group")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub group: Option<models::Group>,
+    pub group: Option<Vec<models::Group>>,
 
 }
 
@@ -492,7 +492,7 @@ impl std::str::FromStr for User {
             pub email: Vec<String>,
             pub phone: Vec<String>,
             pub enabled: Vec<bool>,
-            pub group: Vec<models::Group>,
+            pub group: Vec<Vec<models::Group>>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -514,7 +514,7 @@ impl std::str::FromStr for User {
                     "email" => intermediate_rep.email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "phone" => intermediate_rep.phone.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "enabled" => intermediate_rep.enabled.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "group" => intermediate_rep.group.push(<models::Group as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "group" => return std::result::Result::Err("Parsing a container in this style is not supported in User".to_string()),
                     _ => return std::result::Result::Err("Unexpected key while parsing User".to_string())
                 }
             }
