@@ -26,8 +26,10 @@ use crate::{Api,
      CreateUserResponse,
      DeactivateUserResponse,
      UpdatePasswordResponse,
+     UpdateUserResponse,
      QueryUserByIdResponse,
-     QueryUsersResponse
+     QueryUsersResponse,
+     DeleteSaintResponse
 };
 
 mod paths {
@@ -39,6 +41,7 @@ mod paths {
             r"^/mutation-api/identity-service/users/activation$",
             r"^/mutation-api/identity-service/users/deactivation$",
             r"^/mutation-api/identity-service/users/update-password$",
+            r"^/mutation-api/identity-service/users/(?P<id>[^/?#]*)$",
             r"^/query-api/identity-service/users$",
             r"^/query-api/identity-service/users/(?P<id>[^/?#]*)$"
         ])
@@ -48,8 +51,14 @@ mod paths {
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_ACTIVATION: usize = 1;
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION: usize = 2;
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_UPDATE_PASSWORD: usize = 3;
-    pub(crate) static ID_QUERY_API_IDENTITY_SERVICE_USERS: usize = 4;
-    pub(crate) static ID_QUERY_API_IDENTITY_SERVICE_USERS_ID: usize = 5;
+    pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID: usize = 4;
+    lazy_static! {
+        pub static ref REGEX_MUTATION_API_IDENTITY_SERVICE_USERS_ID: regex::Regex =
+            regex::Regex::new(r"^/mutation-api/identity-service/users/(?P<id>[^/?#]*)$")
+                .expect("Unable to create regex for MUTATION_API_IDENTITY_SERVICE_USERS_ID");
+    }
+    pub(crate) static ID_QUERY_API_IDENTITY_SERVICE_USERS: usize = 5;
+    pub(crate) static ID_QUERY_API_IDENTITY_SERVICE_USERS_ID: usize = 6;
     lazy_static! {
         pub static ref REGEX_QUERY_API_IDENTITY_SERVICE_USERS_ID: regex::Regex =
             regex::Regex::new(r"^/query-api/identity-service/users/(?P<id>[^/?#]*)$")
@@ -535,6 +544,132 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                         }
             },
 
+            // UpdateUser - PUT /mutation-api/identity-service/users/{id}
+            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID) => {
+                {
+                    let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
+                        &Some(ref authorization) => authorization,
+                        &None => return Ok(Response::builder()
+                                                .status(StatusCode::FORBIDDEN)
+                                                .body(Body::from("Unauthenticated"))
+                                                .expect("Unable to create Authentication Forbidden response")),
+                    };
+                }
+
+                // Path parameters
+                let path: &str = &uri.path().to_string();
+                let path_params =
+                    paths::REGEX_MUTATION_API_IDENTITY_SERVICE_USERS_ID
+                    .captures(&path)
+                    .unwrap_or_else(||
+                        panic!("Path {} matched RE MUTATION_API_IDENTITY_SERVICE_USERS_ID in set but failed match against \"{}\"", path, paths::REGEX_MUTATION_API_IDENTITY_SERVICE_USERS_ID.as_str())
+                    );
+
+                let param_id = match percent_encoding::percent_decode(path_params["id"].as_bytes()).decode_utf8() {
+                    Ok(param_id) => match param_id.parse::<uuid::Uuid>() {
+                        Ok(param_id) => param_id,
+                        Err(e) => return Ok(Response::builder()
+                                        .status(StatusCode::BAD_REQUEST)
+                                        .body(Body::from(format!("Couldn't parse path parameter id: {}", e)))
+                                        .expect("Unable to create Bad Request response for invalid path parameter")),
+                    },
+                    Err(_) => return Ok(Response::builder()
+                                        .status(StatusCode::BAD_REQUEST)
+                                        .body(Body::from(format!("Couldn't percent-decode path parameter as UTF-8: {}", &path_params["id"])))
+                                        .expect("Unable to create Bad Request response for invalid percent decode"))
+                };
+
+                // Body parameters (note that non-required body parameters will ignore garbage
+                // values, rather than causing a 400 response). Produce warning header and logs for
+                // any unused fields.
+                let result = body.to_raw().await;
+                match result {
+                            Ok(body) => {
+                                let mut unused_elements = Vec::new();
+                                let param_user: Option<models::User> = if !body.is_empty() {
+                                    let deserializer = &mut serde_json::Deserializer::from_slice(&*body);
+                                    match serde_ignored::deserialize(deserializer, |path| {
+                                            warn!("Ignoring unknown field in body: {}", path);
+                                            unused_elements.push(path.to_string());
+                                    }) {
+                                        Ok(param_user) => param_user,
+                                        Err(e) => return Ok(Response::builder()
+                                                        .status(StatusCode::BAD_REQUEST)
+                                                        .body(Body::from(format!("Couldn't parse body parameter User - doesn't match schema: {}", e)))
+                                                        .expect("Unable to create Bad Request response for invalid body parameter User due to schema")),
+                                    }
+                                } else {
+                                    None
+                                };
+                                let param_user = match param_user {
+                                    Some(param_user) => param_user,
+                                    None => return Ok(Response::builder()
+                                                        .status(StatusCode::BAD_REQUEST)
+                                                        .body(Body::from("Missing required body parameter User"))
+                                                        .expect("Unable to create Bad Request response for missing body parameter User")),
+                                };
+
+                                let result = api_impl.update_user(
+                                            param_id,
+                                            param_user,
+                                        &context
+                                    ).await;
+                                let mut response = Response::new(Body::empty());
+                                response.headers_mut().insert(
+                                            HeaderName::from_static("x-span-id"),
+                                            HeaderValue::from_str((&context as &dyn Has<XSpanIdString>).get().0.clone().to_string().as_str())
+                                                .expect("Unable to create X-Span-ID header value"));
+
+                                        if !unused_elements.is_empty() {
+                                            response.headers_mut().insert(
+                                                HeaderName::from_static("warning"),
+                                                HeaderValue::from_str(format!("Ignoring unknown fields in body: {:?}", unused_elements).as_str())
+                                                    .expect("Unable to create Warning header value"));
+                                        }
+
+                                        match result {
+                                            Ok(rsp) => match rsp {
+                                                UpdateUserResponse::SuccessfulOperation
+                                                    (body)
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(200).expect("Unable to turn 200 into a StatusCode");
+                                                    response.headers_mut().insert(
+                                                        CONTENT_TYPE,
+                                                        HeaderValue::from_str("application/json")
+                                                            .expect("Unable to create Content-Type header for UPDATE_USER_SUCCESSFUL_OPERATION"));
+                                                    let body = serde_json::to_string(&body).expect("impossible to fail to serialize");
+                                                    *response.body_mut() = Body::from(body);
+                                                },
+                                                UpdateUserResponse::InvalidIDSupplied
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(400).expect("Unable to turn 400 into a StatusCode");
+                                                },
+                                                UpdateUserResponse::SaintNotFound
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(404).expect("Unable to turn 404 into a StatusCode");
+                                                },
+                                                UpdateUserResponse::ValidationException
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(405).expect("Unable to turn 405 into a StatusCode");
+                                                },
+                                            },
+                                            Err(_) => {
+                                                // Application code returned an error. This should not happen, as the implementation should
+                                                // return a valid response.
+                                                *response.status_mut() = StatusCode::INTERNAL_SERVER_ERROR;
+                                                *response.body_mut() = Body::from("An internal error occurred");
+                                            },
+                                        }
+
+                                        Ok(response)
+                            },
+                            Err(e) => Ok(Response::builder()
+                                                .status(StatusCode::BAD_REQUEST)
+                                                .body(Body::from(format!("Couldn't read body parameter User: {}", e)))
+                                                .expect("Unable to create Bad Request response due to unable to read body parameter User")),
+                        }
+            },
+
             // QueryUserById - GET /query-api/identity-service/users/{id}
             &hyper::Method::GET if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS_ID) => {
                 {
@@ -778,10 +913,82 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                         Ok(response)
             },
 
+            // DeleteSaint - DELETE /mutation-api/identity-service/users/{id}
+            &hyper::Method::DELETE if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID) => {
+                {
+                    let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
+                        &Some(ref authorization) => authorization,
+                        &None => return Ok(Response::builder()
+                                                .status(StatusCode::FORBIDDEN)
+                                                .body(Body::from("Unauthenticated"))
+                                                .expect("Unable to create Authentication Forbidden response")),
+                    };
+                }
+
+                // Path parameters
+                let path: &str = &uri.path().to_string();
+                let path_params =
+                    paths::REGEX_MUTATION_API_IDENTITY_SERVICE_USERS_ID
+                    .captures(&path)
+                    .unwrap_or_else(||
+                        panic!("Path {} matched RE MUTATION_API_IDENTITY_SERVICE_USERS_ID in set but failed match against \"{}\"", path, paths::REGEX_MUTATION_API_IDENTITY_SERVICE_USERS_ID.as_str())
+                    );
+
+                let param_id = match percent_encoding::percent_decode(path_params["id"].as_bytes()).decode_utf8() {
+                    Ok(param_id) => match param_id.parse::<uuid::Uuid>() {
+                        Ok(param_id) => param_id,
+                        Err(e) => return Ok(Response::builder()
+                                        .status(StatusCode::BAD_REQUEST)
+                                        .body(Body::from(format!("Couldn't parse path parameter id: {}", e)))
+                                        .expect("Unable to create Bad Request response for invalid path parameter")),
+                    },
+                    Err(_) => return Ok(Response::builder()
+                                        .status(StatusCode::BAD_REQUEST)
+                                        .body(Body::from(format!("Couldn't percent-decode path parameter as UTF-8: {}", &path_params["id"])))
+                                        .expect("Unable to create Bad Request response for invalid percent decode"))
+                };
+
+                                let result = api_impl.delete_saint(
+                                            param_id,
+                                        &context
+                                    ).await;
+                                let mut response = Response::new(Body::empty());
+                                response.headers_mut().insert(
+                                            HeaderName::from_static("x-span-id"),
+                                            HeaderValue::from_str((&context as &dyn Has<XSpanIdString>).get().0.clone().to_string().as_str())
+                                                .expect("Unable to create X-Span-ID header value"));
+
+                                        match result {
+                                            Ok(rsp) => match rsp {
+                                                DeleteSaintResponse::SuccessfulOperation
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(200).expect("Unable to turn 200 into a StatusCode");
+                                                },
+                                                DeleteSaintResponse::InvalidIDSupplied
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(400).expect("Unable to turn 400 into a StatusCode");
+                                                },
+                                                DeleteSaintResponse::SaintNotFound
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(404).expect("Unable to turn 404 into a StatusCode");
+                                                },
+                                            },
+                                            Err(_) => {
+                                                // Application code returned an error. This should not happen, as the implementation should
+                                                // return a valid response.
+                                                *response.status_mut() = StatusCode::INTERNAL_SERVER_ERROR;
+                                                *response.body_mut() = Body::from("An internal error occurred");
+                                            },
+                                        }
+
+                                        Ok(response)
+            },
+
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ACTIVATION) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_UPDATE_PASSWORD) => method_not_allowed(),
+            _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID) => method_not_allowed(),
             _ if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS) => method_not_allowed(),
             _ if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS_ID) => method_not_allowed(),
             _ => Ok(Response::builder().status(StatusCode::NOT_FOUND)
@@ -805,10 +1012,14 @@ impl<T> RequestParser<T> for ApiRequestParser {
             &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION) => Ok("DeactivateUser"),
             // UpdatePassword - PUT /mutation-api/identity-service/users/update-password
             &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_UPDATE_PASSWORD) => Ok("UpdatePassword"),
+            // UpdateUser - PUT /mutation-api/identity-service/users/{id}
+            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID) => Ok("UpdateUser"),
             // QueryUserById - GET /query-api/identity-service/users/{id}
             &hyper::Method::GET if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS_ID) => Ok("QueryUserById"),
             // QueryUsers - GET /query-api/identity-service/users
             &hyper::Method::GET if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS) => Ok("QueryUsers"),
+            // DeleteSaint - DELETE /mutation-api/identity-service/users/{id}
+            &hyper::Method::DELETE if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID) => Ok("DeleteSaint"),
             _ => Err(()),
         }
     }
